
#include "VKPileupData.hh"

using namespace std;


VKPileupData::VKPileupData(string fname)
 : fSd(new VKSimData(fname))
{
    // number of events going to output file
    size_t n = fSd->GetEntries();
    if (n % 2 != 0) n -= 1;
    fEntries = n/2;

    // check if tree has V1 or V2 branches
    fHasV2Branches = fSd->HasV2Branches();

    // calculate normalization
    double norm = fSd -> GetNormalization();
    double frac = (double)fEntries / (double)fSd->GetEntries();
    fNormalization = frac * norm * norm / (double)fSd->GetEntries();
}


VKPileupData::~VKPileupData() 
{
    delete fSd;
}


const VKEvent& VKPileupData::GetEvent(size_t id)
{
    size_t i1 = id; // loop forward
    size_t i2 = fSd->GetEntries() - id; // loop backwards 
    const auto& ev1 = fSd -> GetEvent(i1);
    const auto& ev2 = fSd -> GetEvent(i2);
    fEvent.ES = ev1.ES + ev2.ES;
    fEvent.EV = ev1.EV + ev2.EV;
    fEvent.PS = ev1.PS + ev2.PS;
    fEvent.PV = ev1.PV + ev2.PV;
    fEvent.EF2 = ev1.EF2 + ev2.EF2;
    fEvent.ES2 = ev1.ES2 + ev2.ES2;
    fEvent.EV2 = ev1.EV2 + ev2.EV2;
    return fEvent;
}
